)]}'
{"openstack/session.py":[{"author":{"_account_id":8257,"name":"Brian Curtin","email":"brian@python.org","username":"briancurtin"},"change_message_id":"7ea99f54191fc77ccc7c1dd3bca68b295b64ccc8","unresolved":false,"context_lines":[{"line_number":107,"context_line":"        for svc in self.profile.get_services():"},{"line_number":108,"context_line":"            if svc.service_type and svc.api_version:"},{"line_number":109,"context_line":"                req.append(\" \".join([svc.service_type, svc.api_version]))"},{"line_number":110,"context_line":"        if len(req):"},{"line_number":111,"context_line":"            return \", \".join(req)"},{"line_number":112,"context_line":""},{"line_number":113,"context_line":"        return None"}],"source_content_type":"text/x-python","patch_set":4,"id":"bacf61ea_c23ccd31","line":110,"range":{"start_line":110,"start_character":15,"end_line":110,"end_character":18},"updated":"2016-07-28 14:20:32.000000000","message":"Do we want the join to happen even if it\u0027s only a length of one?\n\nIf we do, I would probably make this \"if req\" since we\u0027re not using the benefit of the len call. Or should it be \"if len(req) \u003e 1\" so that we only do the join with multiple items?","commit_id":"dcfe424efddd526ad36f2a8ee5e06e768ae950df"},{"author":{"_account_id":8257,"name":"Brian Curtin","email":"brian@python.org","username":"briancurtin"},"change_message_id":"e44dbcbf87a2341258fca17e4911b482260f157d","unresolved":false,"context_lines":[{"line_number":107,"context_line":"        for svc in self.profile.get_services():"},{"line_number":108,"context_line":"            if svc.service_type and svc.api_version:"},{"line_number":109,"context_line":"                req.append(\" \".join([svc.service_type, svc.api_version]))"},{"line_number":110,"context_line":"        if len(req):"},{"line_number":111,"context_line":"            return \", \".join(req)"},{"line_number":112,"context_line":""},{"line_number":113,"context_line":"        return None"}],"source_content_type":"text/x-python","patch_set":4,"id":"bacf61ea_b1d16232","line":110,"range":{"start_line":110,"start_character":15,"end_line":110,"end_character":18},"in_reply_to":"bacf61ea_03bda1d7","updated":"2016-08-02 12:57:20.000000000","message":"Yeah, that\u0027s not any better, but it does end up having the functionality I was aiming for where we only join multiple items but leave a single item alone.\n\nWhat if you only change the \"if len(req)\" line to \"if req\" and change nothing else? Joining when it\u0027s just a length of one is still correct.","commit_id":"dcfe424efddd526ad36f2a8ee5e06e768ae950df"},{"author":{"_account_id":8246,"name":"Qiming Teng","email":"tengqm@outlook.com","username":"tengqm"},"change_message_id":"476d84b90f4405a9f1530eff2dc23469ad6c9eff","unresolved":false,"context_lines":[{"line_number":107,"context_line":"        for svc in self.profile.get_services():"},{"line_number":108,"context_line":"            if svc.service_type and svc.api_version:"},{"line_number":109,"context_line":"                req.append(\" \".join([svc.service_type, svc.api_version]))"},{"line_number":110,"context_line":"        if len(req):"},{"line_number":111,"context_line":"            return \", \".join(req)"},{"line_number":112,"context_line":""},{"line_number":113,"context_line":"        return None"}],"source_content_type":"text/x-python","patch_set":4,"id":"bacf61ea_03bda1d7","line":110,"range":{"start_line":110,"start_character":15,"end_line":110,"end_character":18},"in_reply_to":"bacf61ea_c23ccd31","updated":"2016-08-02 01:07:02.000000000","message":"em ... tried this, seem readability is no better:\n\n  if req:\n    return \",\".join(req) if len(req) \u003e 1 else req[0]","commit_id":"dcfe424efddd526ad36f2a8ee5e06e768ae950df"}]}
